===========================
oslopolicy-policy-generator
===========================

.. program:: oslopolicy-policy-generator

Synopsis
--------

::

   oslopolicy-policy-generator [-h] [--config-dir DIR] [--config-file PATH]
                               [--namespace NAMESPACE]
                               [--output-file OUTPUT_FILE]

Description
-----------

The ``oslopolicy-policy-generator`` command can be used to generate a policy
file that shows the effective policy in use. This is generated by merging the
registered defaults and policies loaded from a configuration file.

Options
-------

.. include:: common/default-opts.rst

.. include:: common/enforcer-opts.rst

.. include:: common/generator-opts.rst

Examples
--------

The generate the effective policy file for a namespace called ``keystone``:

.. code-block:: bash

   oslopolicy-policy-generator --namespace keystone

To generate the effective policy file and output directly to a file:

.. code-block:: bash

   oslopolicy-policy-generator \
     --namespace keystone \
     --output-file keystone-policy.yaml

To show the additional options and arguments supported by
``oslopolicy-policy-generator``:

.. code-block:: bash

   oslopolicy-policy-generator --help

See Also
--------

:program:`oslopolicy-sample-generator`, :program:`oslopolicy-list-redundant`,
:program:`oslopolicy-checker`
